@@ -21,6 +21,11 @@ has 'release' => (
     default => 1,
 );
 
+has 'pkg_name' => (
+    is      => 'rw',
+    isa     => 'Str',
+);
+
 sub config {
     my ( $self, $key, $value ) = @_;
     die 'key must be passed'   unless $key;
@@ -30,6 +35,17 @@ sub config {
     return $self->conf->{$key}->{$value} || ();
 }
 
+sub get_package_name {
+    my ($self, $module) = @_;
+
+    if ($self->pkg_name) {
+        return $self->pkg_name;
+    }
+    else {
+        return $self->package_name( $module->{module} );
+    }
+}
+
 no Mouse::Role;
 
 1;
